
import sys
from . import printrgb

def main() -> None:
    argv = sys.argv
    ask  = ''
    if argv:
        if len(argv) == 2:
            if argv[1] in ['-h','--help']:
                ask = 'Argvs of Using printrgb\nprintrgb(*values: object,\nforeground_color: list | tuple | None = None,\nbackground_color: list | tuple | None = None,\nsep: str = " ",\nrainbow: bool = False,\nangle_mode : Literal[\'inner\',\'init\',\'random\'] = \'random\',\nend: str = "\\n",\nfile : object | None = None,\nget_color : types.FunctionType | None = None,\nflush: Literal[False] = False'
        printrgb(ask, rainbow = True)
    if not sys.stdin.isatty():
        printrgb(sys.stdin.read(), rainbow = True)

if __name__ == "__main__":
    main()


"""Rainbow terminal printer."""

from .printrgb import printrgb, get_color_default  # 把核心函数/类导出来
import sys
__all__ = ["printrgb", "get_color_default"]
__version__ = "1.1.2"

if __name__ =='__main__':
    printrgb("". join(map(str,sys.argv[1:])), rainbow = 1)
    printrgb(sys.stdin.read(),rainbow = 1)
